@@ -292,14 +292,14 @@ class mediafile(object):
         if self.getmediainfo_done==1:
             return self.mediainfo
         a=os.popen("mediainfo \""+self.address+'"')
-        res=a.read()
+        res=a.read(encoding='utf-8')
         self.dealsubtext(res)
         self.dealaudio(res)
         ss=res.split('\n')
         ss[1]=':'.join([ss[1].split(':')[0],' '+self.filename])
         self.mediainfo='\n'.join(ss)
         a=os.popen("mediainfo --Output=JSON \""+self.address+'"')
-        res_json=a.read()
+        res_json=a.read(encoding='utf-8')
         media_json=json.loads(res_json)
         self.mediainfo_json=media_json
         self.Format            =media_json['media']['track'][0]['Format']
